/*
 * This library is part of the Acacia Editor -
 * an open source inline and form based content editor for GWT.
 *
 * Copyright (c) Alkacon Software GmbH (http://www.alkacon.com)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * For further information about Alkacon Software, please see the
 * company website: http://www.alkacon.com
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package com.alkacon.acacia.shared.rpc;

import com.alkacon.acacia.shared.ContentDefinition;
import com.alkacon.acacia.shared.Entity;
import com.alkacon.acacia.shared.ValidationResult;

import java.util.List;

import com.google.gwt.user.client.rpc.RemoteService;

/**
 * The content service used to load and persist entity and type information.<p>
 * 
 * Implement this on the server side.<p>
 */
public interface I_ContentService extends RemoteService {

    /**
     * Loads the content definition for a given entity.<p>
     * 
     * @param entityId the entity id/URI
     * 
     * @return the content type definition
     * 
     * @throws Exception if something goes wrong processing the request
     */
    ContentDefinition loadContentDefinition(String entityId) throws Exception;

    /**
     * Saves the given entities and returns a validation result in case of invalid entities.<p>
     * Invalid entities will not be saved.<p>
     * 
     * @param entities the entities to save
     * 
     * @return the validation result in case of invalid entities
     * 
     * @throws Exception if something goes wrong processing the request
     */
    ValidationResult saveEntities(List<Entity> entities) throws Exception;

    /**
     * Saves the given entity and returns a validation result in case of invalid entities.<p>
     * Invalid entities will not be saved.<p>
     * 
     * @param entity the entity to save
     * 
     * @return the validation result in case of invalid entities
     * 
     * @throws Exception if something goes wrong processing the request
     */
    ValidationResult saveEntity(Entity entity) throws Exception;

    /**
     * Validates the given entities and returns maps of error and warning messages in case of invalid attributes.<p>
     * 
     * @param changedEntities the entities to validate
     * 
     * @return the validation result
     * 
     * @throws Exception if something goes wrong processing the request
     */
    ValidationResult validateEntities(List<Entity> changedEntities) throws Exception;
}
